var cs__selector_8h =
[
    [ "cs_selector_get_b_face_cells_list", "cs__selector_8h.html#a072669940ac0a340484fa50551149b10", null ],
    [ "cs_selector_get_b_face_list", "cs__selector_8h.html#a2c7591a639ec2810ad813cd2c7611084", null ],
    [ "cs_selector_get_b_face_vertices_list", "cs__selector_8h.html#a497ed8c317db3aedd2bf09c63dd9a52e", null ],
    [ "cs_selector_get_b_face_vertices_list_by_ids", "cs__selector_8h.html#a47d0fba538c631f3a9079cf025122aa4", null ],
    [ "cs_selector_get_cell_list", "cs__selector_8h.html#a1dfe191803929d765301cdcc4a8c5a81", null ],
    [ "cs_selector_get_cell_vertices_list", "cs__selector_8h.html#ae643bd65c9032e63d804024fb150fe8f", null ],
    [ "cs_selector_get_cell_vertices_list_by_ids", "cs__selector_8h.html#a8a5db2fb09249efc18f5c33dcfeab58d", null ],
    [ "cs_selector_get_cells_boundary", "cs__selector_8h.html#ac0c48abfdcbc141c97598d327925d74b", null ],
    [ "cs_selector_get_family_list", "cs__selector_8h.html#ae129628578639ad3db640932661ce9d0", null ],
    [ "cs_selector_get_i_face_list", "cs__selector_8h.html#af8459d78ef1b0df7ac239f9f2435913a", null ],
    [ "cs_selector_get_perio_face_list", "cs__selector_8h.html#a6b7300586d93b906a70a687be9ca1c88", null ]
];